<template>
    <table class="table">
        <thead class="table__head">
            <tr class="table__head-row">
                <td class="table__head-item">
                    Режим
                </td>
                <td class="table__head-item hide-on-mobile">
                    Игрок
                </td>
                <td class="table__head-item hide-on-xs">
                    Сумма
                </td>
                <td class="table__head-item">
                    Коэффициент
                </td>
                <td class="table__head-item">
                    Результат
                </td>
            </tr>
        </thead>
        <tbody class="table__body">
            <tr
                class="table__body-row"
                v-for="game in games"
                :key="game.id"
            >
                <td class="table__body-item">
                    <div class="game__icon dice" v-if="game.type == 'dice'"></div>
                    <div class="game__icon bubbles" v-if="game.type == 'bubbles'"></div>
                    <svg class="icon mines" v-if="game.type == 'mines'"><use xlink:href="/assets/img/symbols.svg?v=1#icon-mines"></use></svg>
                </td>
                <td class="table__body-item hide-on-mobile">
                    <span 
                        @click="$root.$emit('showProfile', game.user_id)" 
                        style="cursor: pointer"
                    >
                        {{ game.username }}
                    </span>
                </td>
                <td class="table__body-item hide-on-xs">
                    {{ Number(game.amount).toFixed(2) }}
                </td>
                <td class="table__body-item">
                    x{{ game.coeff }}
                </td>
                <td class="table__body-item" :class="[game.result > 0 ? 'bg-success' : 'bg-danger']">
                    {{ Number(game.result).toFixed(2) }}
                </td>
            </tr>
        </tbody>
    </table>
</template>

<script>
export default {
    data() {
        return {
            games: []
        }
    },
    sockets: {
        newGame(game) {
            if(this.games.length > 10) {
                this.games.pop();
            }

            this.games.unshift(game);
        }
    }
}
</script>

<style scoped>
.table__head-item {
    padding: 18px 32px!important;
}

.game__icon.dice {
    mask: url(/assets/img/icon/games/dice.svg);
    -webkit-mask: url(/assets/img/icon/games/dice.svg) no-repeat center;
    background-color: #2c80ff;
    height: 32px;
}

.game__icon.bubbles {
    mask: url(/assets/img/icon/games/bubbles.svg);
    -webkit-mask: url(/assets/img/icon/games/bubbles.svg) no-repeat center;
    background-color: #2c80ff;
    height: 32px;
}

svg.mines {
    fill: #2c80ff;
    width: 28px!important;
    height: 28px!important;
}

.bg-success, .bg-danger {
    font-weight: 900;
}

.bg-success {
    color: #0cbf88
}

.bg-danger {
    color: #EB3349
}
</style>
